/************************************************************************
 *   IRC - Internet Relay Chat, src/paths.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

/* This brings all the paths together in one place, so that
 * you don't have to rebuild the entire tree every time they change,
 * and so that they can move to a config file later
 *  -- asuffield
 */

#include "paths.h"

/* DPATH SPATH CPATH MPATH KPATH - directoy and files locations
 * Full pathnames and defaults of irc system's support files. Please note that
 * these are only the recommended names and paths. Change as needed.
 * You must define these to something, even if you don't really want them.
 *
 * DPATH = directory,
 * SPATH = server executable,
 * CPATH = conf file,
 * MPATH = MOTD
 * KPATH = kline conf file
 * DLPATH = dline conf file
 *
 * OMOTD = path to MOTD for opers
 * MCPATH = path to modules.conf
 * 
 * For /restart to work, SPATH needs to be a full pathname
 * (unless "." is in your exec path). -Rodder
 * Leave KPATH undefined if you want klines in main conf file.
 * HPATH is the opers help file, seen by opers on /quote help.
 * -Dianora
 *
 * DPATH must have a trailing /
 * Do not use ~'s in any of these paths
 *
 */

#define DPATH   LOCALSTATEDIR "/lib/dancer-ircd/"
#define SPATH   SBINDIR "/dancer-ircd"
#define CPATH   SYSCONFDIR "/dancer-ircd/ircd.conf"
#define MCPATH  SYSCONFDIR "/dancer-ircd/modules.conf"
#define DLPATH  LOCALSTATEDIR "/lib/dancer-ircd/dline.conf"
#define MPATH   SYSCONFDIR "/dancer-ircd/motd"
#define LPATH   LOCALSTATEDIR "/log/dancer-ircd/ircd.log"
#define PPATH   LOCALSTATEDIR "/run/dancer-ircd.pid"
#define HPATH   SYSCONFDIR "/dancer-ircd/ohelp"
#define OPATH   SYSCONFDIR "/dancer-ircd/omotd"
#define DBPATH  LOCALSTATEDIR "/lib/dancer-ircd/db"

char *work_dir = DPATH;
char *config_file = CPATH;
char *my_binary = SPATH;
char *mod_config_file = MCPATH;
char *motd_file = MPATH;
char *main_log_file = LPATH;
char *pid_file = PPATH;
char *oper_help_file = HPATH;
char *oper_motd_file = OPATH;
char *database_env_dir = DBPATH;
